#' List of grid square codes by Japanese municipalities
#'
#' @source <https://www.stat.go.jp/data/mesh/m_itiran.html>
"grid_city_2020"
